#version 100

precision mediump float;

// Input vertex attributes (from vertex shader)
varying vec2 fragTexCoord;
varying vec4 fragColor;

// Input uniform values
uniform sampler2D texture0;
uniform vec4 colDiffuse;

uniform vec2 textureSize;
uniform float outlineSize;
uniform vec4 outlineColor;

void main()
{
    vec4 texel = texture2D(texture0, fragTexCoord);   // Get texel color
    vec2 texelScale = vec2(0.0);
    texelScale.x = outlineSize/textureSize.x;
    texelScale.y = outlineSize/textureSize.y;

    // We sample four corner texels, but only for the alpha channel (this is for the outline)
    vec4 corners = vec4(0.0);
    vec4 tx1 = texture2D(texture0, fragTexCoord + vec2(texelScale.x, texelScale.y));
    vec4 tx2 = texture2D(texture0, fragTexCoord + vec2(texelScale.x, -texelScale.y));
    vec4 tx3 = texture2D(texture0, fragTexCoord + vec2(-texelScale.x, texelScale.y));
    vec4 tx4 = texture2D(texture0, fragTexCoord + vec2(-texelScale.x, -texelScale.y));
    vec4 diff1 = tx1 - tx4;
    vec4 diff2 = tx2 - tx3;
    float diff = (length(diff1) + length(diff2)) * 255.0;

    float outline = diff > 0.5 ? 1.0 : 0.0;
    vec4 color = mix(texel, outlineColor, outline);
    gl_FragColor = color;
}